# bitrise (EXPERIMENTAL)
Official REST API for Bitrise.io

This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1
- Build package: org.openapitools.codegen.languages.DartDioNextClientCodegen
For more information, please visit [https://www.bitrise.io/contact](https://www.bitrise.io/contact)

## Requirements

* Dart 2.12.0 or later OR Flutter 1.26.0 or later
* Dio 4.0.0+

## Installation & Usage

### pub.dev
To use the package from [pub.dev](https://pub.dev), please include the following in pubspec.yaml
```yaml
dependencies:
  bitrise: 1.0.0
```

### Github
If this Dart package is published to Github, please include the following in pubspec.yaml
```yaml
dependencies:
  bitrise:
    git:
      url: https://github.com/GIT_USER_ID/GIT_REPO_ID.git
      #ref: main
```

### Local development
To use the package from your local drive, please include the following in pubspec.yaml
```yaml
dependencies:
  bitrise:
    path: /path/to/bitrise
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:bitrise/bitrise.dart';


final api = ActivityApi();
final next = next_example; // String | Slug of the first activity event in the response
final limit = 56; // int | Max number of elements per page (default: 50)

try {
    final response = await api.activityList(next, limit);
    print(response);
} catch on DioError (e) {
    print("Exception when calling ActivityApi->activityList: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *https://api.bitrise.io/v0.1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActivityApi* | [**activityList**](doc/ActivityApi.md#activitylist) | **get** /me/activities | Get list of Bitrise activity events
*AddonsApi* | [**addonListByApp**](doc/AddonsApi.md#addonlistbyapp) | **get** /apps/{app-slug}/addons | Get list of the addons for apps
*AddonsApi* | [**addonListByOrganization**](doc/AddonsApi.md#addonlistbyorganization) | **get** /organizations/{organization-slug}/addons | Get list of the addons for organization
*AddonsApi* | [**addonListByUser**](doc/AddonsApi.md#addonlistbyuser) | **get** /users/{user-slug}/addons | Get list of the addons for user
*AddonsApi* | [**addonsList**](doc/AddonsApi.md#addonslist) | **get** /addons | Get list of available Bitrise addons
*AddonsApi* | [**addonsShow**](doc/AddonsApi.md#addonsshow) | **get** /addons/{addon-id} | Get a specific Bitrise addon
*AndroidKeystoreFileApi* | [**androidKeystoreFileCreate**](doc/AndroidKeystoreFileApi.md#androidkeystorefilecreate) | **post** /apps/{app-slug}/android-keystore-files | Create an Android keystore file
*AndroidKeystoreFileApi* | [**androidKeystoreFileList**](doc/AndroidKeystoreFileApi.md#androidkeystorefilelist) | **get** /apps/{app-slug}/android-keystore-files | Get a list of the android keystore files
*AppSetupApi* | [**appConfigCreate**](doc/AppSetupApi.md#appconfigcreate) | **post** /apps/{app-slug}/bitrise.yml | Upload a new bitrise.yml for your application.
*AppSetupApi* | [**appCreate**](doc/AppSetupApi.md#appcreate) | **post** /apps/register | Add a new app
*AppSetupApi* | [**appFinish**](doc/AppSetupApi.md#appfinish) | **post** /apps/{app-slug}/finish | Save the application at the end of the app registration process
*AppSetupApi* | [**appWebhookCreate**](doc/AppSetupApi.md#appwebhookcreate) | **post** /apps/{app-slug}/register-webhook | Register an incoming webhook for a specific application
*AppSetupApi* | [**sshKeyCreate**](doc/AppSetupApi.md#sshkeycreate) | **post** /apps/{app-slug}/register-ssh-key | Add an SSH-key to a specific app
*AppleApiCredentialsApi* | [**appleApiCredentialList**](doc/AppleApiCredentialsApi.md#appleapicredentiallist) | **get** /users/{user-slug}/apple-api-credentials | List Apple API credentials for a specific user
*ApplicationApi* | [**appConfigDatastoreShow**](doc/ApplicationApi.md#appconfigdatastoreshow) | **get** /apps/{app-slug}/bitrise.yml | Get bitrise.yml of a specific app
*ApplicationApi* | [**appList**](doc/ApplicationApi.md#applist) | **get** /apps | Get list of the apps
*ApplicationApi* | [**appListByOrganization**](doc/ApplicationApi.md#applistbyorganization) | **get** /organizations/{org-slug}/apps | Get list of the apps for an organization
*ApplicationApi* | [**appListByUser**](doc/ApplicationApi.md#applistbyuser) | **get** /users/{user-slug}/apps | Get list of the apps for a user
*ApplicationApi* | [**appShow**](doc/ApplicationApi.md#appshow) | **get** /apps/{app-slug} | Get a specific app
*ApplicationApi* | [**branchList**](doc/ApplicationApi.md#branchlist) | **get** /apps/{app-slug}/branches | List the branches with existing builds of an app&#39;s repository
*AvatarCandidateApi* | [**avatarCandidateCreate**](doc/AvatarCandidateApi.md#avatarcandidatecreate) | **post** /apps/{app-slug}/avatar-candidates | Create avatar candidates
*AvatarCandidateApi* | [**avatarCandidateList**](doc/AvatarCandidateApi.md#avatarcandidatelist) | **get** /v0.1/apps/{app-slug}/avatar-candidates | Get list of the avatar candidates
*AvatarCandidateApi* | [**avatarCandidatePromote**](doc/AvatarCandidateApi.md#avatarcandidatepromote) | **patch** /apps/{app-slug}/avatar-candidates/{avatar-slug} | Promote an avatar candidate
*BuildArtifactApi* | [**artifactDelete**](doc/BuildArtifactApi.md#artifactdelete) | **delete** /apps/{app-slug}/builds/{build-slug}/artifacts/{artifact-slug} | Delete a build artifact
*BuildArtifactApi* | [**artifactList**](doc/BuildArtifactApi.md#artifactlist) | **get** /apps/{app-slug}/builds/{build-slug}/artifacts | Get a list of all build artifacts
*BuildArtifactApi* | [**artifactShow**](doc/BuildArtifactApi.md#artifactshow) | **get** /apps/{app-slug}/builds/{build-slug}/artifacts/{artifact-slug} | Get a specific build artifact
*BuildArtifactApi* | [**artifactUpdate**](doc/BuildArtifactApi.md#artifactupdate) | **patch** /apps/{app-slug}/builds/{build-slug}/artifacts/{artifact-slug} | Update a build artifact
*BuildCertificateApi* | [**buildCertificateConfirm**](doc/BuildCertificateApi.md#buildcertificateconfirm) | **post** /apps/{app-slug}/build-certificates/{build-certificate-slug}/uploaded | Confirm a build certificate upload
*BuildCertificateApi* | [**buildCertificateCreate**](doc/BuildCertificateApi.md#buildcertificatecreate) | **post** /apps/{app-slug}/build-certificates | Create a build certificate
*BuildCertificateApi* | [**buildCertificateDelete**](doc/BuildCertificateApi.md#buildcertificatedelete) | **delete** /apps/{app-slug}/build-certificates/{build-certificate-slug} | Delete a build certificate
*BuildCertificateApi* | [**buildCertificateList**](doc/BuildCertificateApi.md#buildcertificatelist) | **get** /apps/{app-slug}/build-certificates | Get a list of the build certificates
*BuildCertificateApi* | [**buildCertificateShow**](doc/BuildCertificateApi.md#buildcertificateshow) | **get** /apps/{app-slug}/build-certificates/{build-certificate-slug} | Get a specific build certificate
*BuildCertificateApi* | [**buildCertificateUpdate**](doc/BuildCertificateApi.md#buildcertificateupdate) | **patch** /apps/{app-slug}/build-certificates/{build-certificate-slug} | Update a build certificate
*BuildRequestApi* | [**buildRequestList**](doc/BuildRequestApi.md#buildrequestlist) | **get** /apps/{app-slug}/build-requests | List the open build requests for an app
*BuildRequestApi* | [**buildRequestUpdate**](doc/BuildRequestApi.md#buildrequestupdate) | **patch** /apps/{app-slug}/build-requests/{build-request-slug} | Update a build request
*BuildsApi* | [**buildAbort**](doc/BuildsApi.md#buildabort) | **post** /apps/{app-slug}/builds/{build-slug}/abort | Abort a specific build
*BuildsApi* | [**buildBitriseYmlShow**](doc/BuildsApi.md#buildbitriseymlshow) | **get** /apps/{app-slug}/builds/{build-slug}/bitrise.yml | Get the bitrise.yml of a build
*BuildsApi* | [**buildList**](doc/BuildsApi.md#buildlist) | **get** /apps/{app-slug}/builds | List all builds of an app
*BuildsApi* | [**buildListAll**](doc/BuildsApi.md#buildlistall) | **get** /builds | List all builds
*BuildsApi* | [**buildLog**](doc/BuildsApi.md#buildlog) | **get** /apps/{app-slug}/builds/{build-slug}/log | Get the build log of a build
*BuildsApi* | [**buildShow**](doc/BuildsApi.md#buildshow) | **get** /apps/{app-slug}/builds/{build-slug} | Get a build of a given app
*BuildsApi* | [**buildTrigger**](doc/BuildsApi.md#buildtrigger) | **post** /apps/{app-slug}/builds | Trigger a new build
*BuildsApi* | [**buildWorkflowList**](doc/BuildsApi.md#buildworkflowlist) | **get** /apps/{app-slug}/build-workflows | List the workflows of an app
*GenericProjectFileApi* | [**genericProjectFileConfirm**](doc/GenericProjectFileApi.md#genericprojectfileconfirm) | **post** /apps/{app-slug}/generic-project-files/{generic-project-file-slug}/uploaded | Confirm a generic project file upload
*GenericProjectFileApi* | [**genericProjectFileDelete**](doc/GenericProjectFileApi.md#genericprojectfiledelete) | **delete** /apps/{app-slug}/generic-project-files/{generic-project-file-slug} | Delete a generic project file
*GenericProjectFileApi* | [**genericProjectFileList**](doc/GenericProjectFileApi.md#genericprojectfilelist) | **get** /apps/{app-slug}/generic-project-files | Get a list of the generic project files
*GenericProjectFileApi* | [**genericProjectFileShow**](doc/GenericProjectFileApi.md#genericprojectfileshow) | **get** /apps/{app-slug}/generic-project-files/{generic-project-file-slug} | Get a specific generic project file
*GenericProjectFileApi* | [**genericProjectFileUpdate**](doc/GenericProjectFileApi.md#genericprojectfileupdate) | **patch** /apps/{app-slug}/generic-project-files/{generic-project-file-slug} | Update a generic project file
*GenericProjectFileApi* | [**genericProjectFilesCreate**](doc/GenericProjectFileApi.md#genericprojectfilescreate) | **post** /apps/{app-slug}/generic-project-files | Create a generic project file
*OrganizationsApi* | [**orgList**](doc/OrganizationsApi.md#orglist) | **get** /organizations | List the organizations that the user is part of
*OrganizationsApi* | [**orgShow**](doc/OrganizationsApi.md#orgshow) | **get** /organizations/{org-slug} | Get a specified organization.
*OutgoingWebhookApi* | [**outgoingWebhookCreate**](doc/OutgoingWebhookApi.md#outgoingwebhookcreate) | **post** /apps/{app-slug}/outgoing-webhooks | Create an outgoing webhook for an app
*OutgoingWebhookApi* | [**outgoingWebhookDelete**](doc/OutgoingWebhookApi.md#outgoingwebhookdelete) | **delete** /apps/{app-slug}/outgoing-webhooks/{app-webhook-slug} | Delete an outgoing webhook of an app
*OutgoingWebhookApi* | [**outgoingWebhookList**](doc/OutgoingWebhookApi.md#outgoingwebhooklist) | **get** /apps/{app-slug}/outgoing-webhooks | List the outgoing webhooks of an app
*OutgoingWebhookApi* | [**outgoingWebhookUpdate**](doc/OutgoingWebhookApi.md#outgoingwebhookupdate) | **put** /apps/{app-slug}/outgoing-webhooks/{app-webhook-slug} | Update an outgoing webhook of an app
*ProvisioningProfileApi* | [**provisioningProfileConfirm**](doc/ProvisioningProfileApi.md#provisioningprofileconfirm) | **post** /apps/{app-slug}/provisioning-profiles/{provisioning-profile-slug}/uploaded | Confirm a provisioning profile upload
*ProvisioningProfileApi* | [**provisioningProfileCreate**](doc/ProvisioningProfileApi.md#provisioningprofilecreate) | **post** /apps/{app-slug}/provisioning-profiles | Create a provisioning profile
*ProvisioningProfileApi* | [**provisioningProfileDelete**](doc/ProvisioningProfileApi.md#provisioningprofiledelete) | **delete** /apps/{app-slug}/provisioning-profiles/{provisioning-profile-slug} | Delete a provisioning profile
*ProvisioningProfileApi* | [**provisioningProfileList**](doc/ProvisioningProfileApi.md#provisioningprofilelist) | **get** /apps/{app-slug}/provisioning-profiles | Get a list of the provisioning profiles
*ProvisioningProfileApi* | [**provisioningProfileShow**](doc/ProvisioningProfileApi.md#provisioningprofileshow) | **get** /apps/{app-slug}/provisioning-profiles/{provisioning-profile-slug} | Get a specific provisioning profile
*ProvisioningProfileApi* | [**provisioningProfileUpdate**](doc/ProvisioningProfileApi.md#provisioningprofileupdate) | **patch** /apps/{app-slug}/provisioning-profiles/{provisioning-profile-slug} | Update a provisioning profile
*TestDevicesApi* | [**testDeviceList**](doc/TestDevicesApi.md#testdevicelist) | **get** /apps/{app-slug}/test-devices | List the test devices for an app
*UserApi* | [**userPlan**](doc/UserApi.md#userplan) | **get** /me/plan | The subscription plan of the user
*UserApi* | [**userProfile**](doc/UserApi.md#userprofile) | **get** /me | Get your profile data
*UserApi* | [**userShow**](doc/UserApi.md#usershow) | **get** /users/{user-slug} | Get a specific user
*WebhookDeliveryItemApi* | [**webhookDeliveryItemList**](doc/WebhookDeliveryItemApi.md#webhookdeliveryitemlist) | **get** /apps/{app-slug}/outgoing-webhooks/{app-webhook-slug}/delivery-items | List the webhook delivery items of an app
*WebhookDeliveryItemApi* | [**webhookDeliveryItemRedeliver**](doc/WebhookDeliveryItemApi.md#webhookdeliveryitemredeliver) | **post** /apps/{app-slug}/outgoing-webhooks/{app-webhook-slug}/delivery-items/{webhook-delivery-item-slug}/redeliver | Re-deliver the webhook delivery items of an app
*WebhookDeliveryItemApi* | [**webhookDeliveryItemShow**](doc/WebhookDeliveryItemApi.md#webhookdeliveryitemshow) | **get** /apps/{app-slug}/outgoing-webhooks/{app-webhook-slug}/delivery-items/{webhook-delivery-item-slug} | Get a specific delivery item of a webhook


## Documentation For Models

 - [AddonsAddon](doc/AddonsAddon.md)
 - [AddonsDeveloperLink](doc/AddonsDeveloperLink.md)
 - [AddonsFeature](doc/AddonsFeature.md)
 - [AddonsPlan](doc/AddonsPlan.md)
 - [AddonsSetupGuide](doc/AddonsSetupGuide.md)
 - [AddonsSetupInstruction](doc/AddonsSetupInstruction.md)
 - [NullsInt64](doc/NullsInt64.md)
 - [NullsString](doc/NullsString.md)
 - [ServiceStandardErrorRespModel](doc/ServiceStandardErrorRespModel.md)
 - [V0ActivityEventListResponseModel](doc/V0ActivityEventListResponseModel.md)
 - [V0ActivityEventResponseItemModel](doc/V0ActivityEventResponseItemModel.md)
 - [V0AddOnAppResponseItemModel](doc/V0AddOnAppResponseItemModel.md)
 - [V0AddonsListResponseModel](doc/V0AddonsListResponseModel.md)
 - [V0AddonsShowResponseModel](doc/V0AddonsShowResponseModel.md)
 - [V0AndroidKeystoreFileUploadParams](doc/V0AndroidKeystoreFileUploadParams.md)
 - [V0AppAddOnResponseItemModel](doc/V0AppAddOnResponseItemModel.md)
 - [V0AppAddOnsListResponseModel](doc/V0AppAddOnsListResponseModel.md)
 - [V0AppConfigRequestParam](doc/V0AppConfigRequestParam.md)
 - [V0AppFinishParams](doc/V0AppFinishParams.md)
 - [V0AppFinishRespModel](doc/V0AppFinishRespModel.md)
 - [V0AppListResponseModel](doc/V0AppListResponseModel.md)
 - [V0AppRespModel](doc/V0AppRespModel.md)
 - [V0AppResponseItemModel](doc/V0AppResponseItemModel.md)
 - [V0AppShowResponseModel](doc/V0AppShowResponseModel.md)
 - [V0AppUploadParams](doc/V0AppUploadParams.md)
 - [V0AppWebhookCreateParams](doc/V0AppWebhookCreateParams.md)
 - [V0AppWebhookCreatedResponseModel](doc/V0AppWebhookCreatedResponseModel.md)
 - [V0AppWebhookDeletedResponseModel](doc/V0AppWebhookDeletedResponseModel.md)
 - [V0AppWebhookListResponseModel](doc/V0AppWebhookListResponseModel.md)
 - [V0AppWebhookResponseItemModel](doc/V0AppWebhookResponseItemModel.md)
 - [V0AppWebhookResponseModel](doc/V0AppWebhookResponseModel.md)
 - [V0AppWebhookUpdateParams](doc/V0AppWebhookUpdateParams.md)
 - [V0AppleAPICredentialResponseItem](doc/V0AppleAPICredentialResponseItem.md)
 - [V0AppleAPICredentialsListResponse](doc/V0AppleAPICredentialsListResponse.md)
 - [V0ArtifactDeleteResponseModel](doc/V0ArtifactDeleteResponseModel.md)
 - [V0ArtifactListElementResponseModel](doc/V0ArtifactListElementResponseModel.md)
 - [V0ArtifactListResponseModel](doc/V0ArtifactListResponseModel.md)
 - [V0ArtifactResponseItemModel](doc/V0ArtifactResponseItemModel.md)
 - [V0ArtifactShowResponseModel](doc/V0ArtifactShowResponseModel.md)
 - [V0ArtifactUpdateParams](doc/V0ArtifactUpdateParams.md)
 - [V0AvatarCandidateCreateParams](doc/V0AvatarCandidateCreateParams.md)
 - [V0AvatarCandidateCreateResponseItem](doc/V0AvatarCandidateCreateResponseItem.md)
 - [V0AvatarPromoteParams](doc/V0AvatarPromoteParams.md)
 - [V0AvatarPromoteResponseItemModel](doc/V0AvatarPromoteResponseItemModel.md)
 - [V0AvatarPromoteResponseModel](doc/V0AvatarPromoteResponseModel.md)
 - [V0BranchListResponseModel](doc/V0BranchListResponseModel.md)
 - [V0BuildAbortParams](doc/V0BuildAbortParams.md)
 - [V0BuildAbortResponseModel](doc/V0BuildAbortResponseModel.md)
 - [V0BuildCertificateListResponseModel](doc/V0BuildCertificateListResponseModel.md)
 - [V0BuildCertificateResponseItemModel](doc/V0BuildCertificateResponseItemModel.md)
 - [V0BuildCertificateResponseModel](doc/V0BuildCertificateResponseModel.md)
 - [V0BuildCertificateUpdateParams](doc/V0BuildCertificateUpdateParams.md)
 - [V0BuildCertificateUploadParams](doc/V0BuildCertificateUploadParams.md)
 - [V0BuildListAllResponseItemModel](doc/V0BuildListAllResponseItemModel.md)
 - [V0BuildListAllResponseModel](doc/V0BuildListAllResponseModel.md)
 - [V0BuildListResponseModel](doc/V0BuildListResponseModel.md)
 - [V0BuildLogChunkItemResponseModel](doc/V0BuildLogChunkItemResponseModel.md)
 - [V0BuildLogInfoResponseModel](doc/V0BuildLogInfoResponseModel.md)
 - [V0BuildParamsEnvironment](doc/V0BuildParamsEnvironment.md)
 - [V0BuildRequestListResponseModel](doc/V0BuildRequestListResponseModel.md)
 - [V0BuildRequestResponseItemModel](doc/V0BuildRequestResponseItemModel.md)
 - [V0BuildRequestUpdateParams](doc/V0BuildRequestUpdateParams.md)
 - [V0BuildRequestUpdateResponseModel](doc/V0BuildRequestUpdateResponseModel.md)
 - [V0BuildResponseItemModel](doc/V0BuildResponseItemModel.md)
 - [V0BuildShowResponseModel](doc/V0BuildShowResponseModel.md)
 - [V0BuildTriggerParams](doc/V0BuildTriggerParams.md)
 - [V0BuildTriggerParamsBuildParams](doc/V0BuildTriggerParamsBuildParams.md)
 - [V0BuildTriggerParamsHookInfo](doc/V0BuildTriggerParamsHookInfo.md)
 - [V0BuildTriggerRespModel](doc/V0BuildTriggerRespModel.md)
 - [V0BuildWorkflowListResponseModel](doc/V0BuildWorkflowListResponseModel.md)
 - [V0CommitPaths](doc/V0CommitPaths.md)
 - [V0FindAvatarCandidateResponse](doc/V0FindAvatarCandidateResponse.md)
 - [V0FindAvatarCandidateResponseItem](doc/V0FindAvatarCandidateResponseItem.md)
 - [V0OrganizationDataModel](doc/V0OrganizationDataModel.md)
 - [V0OrganizationListRespModel](doc/V0OrganizationListRespModel.md)
 - [V0OrganizationOwner](doc/V0OrganizationOwner.md)
 - [V0OrganizationRespModel](doc/V0OrganizationRespModel.md)
 - [V0OwnerAccountResponseModel](doc/V0OwnerAccountResponseModel.md)
 - [V0OwnerAddOnResponseItemModel](doc/V0OwnerAddOnResponseItemModel.md)
 - [V0OwnerAddOnsListResponseModel](doc/V0OwnerAddOnsListResponseModel.md)
 - [V0PagingResponseModel](doc/V0PagingResponseModel.md)
 - [V0PlanDataModel](doc/V0PlanDataModel.md)
 - [V0ProjectFileStorageDocumentUpdateParams](doc/V0ProjectFileStorageDocumentUpdateParams.md)
 - [V0ProjectFileStorageListResponseModel](doc/V0ProjectFileStorageListResponseModel.md)
 - [V0ProjectFileStorageResponseItemModel](doc/V0ProjectFileStorageResponseItemModel.md)
 - [V0ProjectFileStorageResponseModel](doc/V0ProjectFileStorageResponseModel.md)
 - [V0ProjectFileStorageUploadParams](doc/V0ProjectFileStorageUploadParams.md)
 - [V0ProvProfileDocumentUpdateParams](doc/V0ProvProfileDocumentUpdateParams.md)
 - [V0ProvisionProfileListResponseModel](doc/V0ProvisionProfileListResponseModel.md)
 - [V0ProvisionProfileResponseItemModel](doc/V0ProvisionProfileResponseItemModel.md)
 - [V0ProvisionProfileResponseModel](doc/V0ProvisionProfileResponseModel.md)
 - [V0ProvisionProfileUploadParams](doc/V0ProvisionProfileUploadParams.md)
 - [V0ProxyErrorRespModel](doc/V0ProxyErrorRespModel.md)
 - [V0SSHKeyRespModel](doc/V0SSHKeyRespModel.md)
 - [V0SSHKeyUploadParams](doc/V0SSHKeyUploadParams.md)
 - [V0TestDeviceListResponseModel](doc/V0TestDeviceListResponseModel.md)
 - [V0TestDeviceResponseItemModel](doc/V0TestDeviceResponseItemModel.md)
 - [V0UserPlanDataModel](doc/V0UserPlanDataModel.md)
 - [V0UserPlanRespModel](doc/V0UserPlanRespModel.md)
 - [V0UserProfileDataModel](doc/V0UserProfileDataModel.md)
 - [V0UserProfileRespModel](doc/V0UserProfileRespModel.md)
 - [V0WebhookDeliveryItemResponseModel](doc/V0WebhookDeliveryItemResponseModel.md)
 - [V0WebhookDeliveryItemShowResponseModel](doc/V0WebhookDeliveryItemShowResponseModel.md)
 - [V0WebhookRespModel](doc/V0WebhookRespModel.md)


## Documentation For Authorization


## AddonAuthToken

- **Type**: API key
- **API key parameter name**: Bitrise-Addon-Auth-Token
- **Location**: HTTP header

## PersonalAccessToken

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

letsconnect@bitrise.io


